.. _pipelines:

Pipelines
---------

Process MTH5
************

.. automodule:: aurora.pipelines.process_mth5
    :show-inheritance:
    :members:
    :undoc-members:


Time Series Helpers
*******************

.. automodule:: aurora.pipelines.time_series_helpers
    :show-inheritance:
    :members:
    :undoc-members:


Transfer Function Helpers
*************************

.. automodule:: aurora.pipelines.transfer_function_helpers
    :show-inheritance:
    :members:
    :undoc-members:



